@@ -51,7 +51,7 @@ class DeepSet:
         self,
         phi,
         rho,
-        agg=lambda x: B.mean(x, axis=2, squeeze=False),
+        agg=lambda x: B.sum(x, axis=2, squeeze=False),
     ):
         self.phi = phi
         self.rho = rho
@@ -59,7 +59,7 @@ class DeepSet:
 
 
 @_dispatch
-def code(coder: DeepSet, xz, z, x):
+def code(coder: DeepSet, xz, z, x, **kw_args):
     z = B.concat(xz, z, axis=1)
     z = coder.phi(z)
     z = coder.agg(z)  # This aggregates over the data dimension.
